"""
RSA_tool module

eng: Module for fast calculating large primes, and RSA encryption and decryption of data of any size.

rus: Модуль сделан для быстрого вычисления простых чисел, и шифрования/расшифрования данных любого размера по алгоритму RSA


"""
from .RSA_tool import RSA


__author__ = "Nikita Grigorev, Andrey Ignatov"
__date__ = "2023-03-22"
__version__ = "1.1"